package com.example.development.mainActivity.components

import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.Image
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.PasswordVisualTransformation
import androidx.compose.ui.text.input.VisualTransformation
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavHostController
import com.example.development.R
import com.example.development.ui.theme.OldStandart
import com.example.development.mainActivity.MainViewModel

@Composable
fun RegistrationScreen(navController: NavHostController, viewModel: MainViewModel) {
    val viewModel = MainViewModel()
    val email = remember { mutableStateOf("") }
    val password = remember { mutableStateOf("") }
    Box(contentAlignment = Alignment.TopCenter,
        modifier = Modifier
            .fillMaxSize()
    )
    {
        Image(
            painter = painterResource(id = R.drawable.fone),
            contentDescription = "",
            contentScale = ContentScale.FillWidth,
            modifier = Modifier.fillMaxWidth().fillMaxHeight()
        )
        Column(modifier = Modifier.fillMaxSize(), verticalArrangement = Arrangement.SpaceAround, horizontalAlignment = Alignment.CenterHorizontally)
        {
            Column(verticalArrangement = Arrangement.Top, horizontalAlignment = Alignment.CenterHorizontally)
            {
                Image(
                    painter = painterResource(id = R.drawable.logo),
                    contentDescription = "",
                    contentScale = ContentScale.FillHeight,
                    modifier = Modifier.height(150.dp).width(150.dp)
                )
            }
            Column(verticalArrangement = Arrangement.Center, horizontalAlignment = Alignment.CenterHorizontally, )
            {
                Text(
                    "РЕГИСТРАЦИЯ",
                    color = Color.White,
                    modifier = Modifier.padding(bottom = 50.dp),
                    fontSize = 30.sp,
                    fontWeight = FontWeight.Bold,
                    fontFamily = OldStandart
                )
                Column(
                    modifier = Modifier
                        .padding(),
                    verticalArrangement = Arrangement.Center,
                    horizontalAlignment = Alignment.CenterHorizontally
                )
                {
                    TextField(
                        value = "Логин",
                        onValueChange = {},
                        Modifier.padding(bottom = 5.dp).width(280.dp)
                    )
                    Column(
                        modifier = Modifier
                            .padding(top = 0.dp)
                    )
                    {
                        var passwordVisibility: Boolean by remember { mutableStateOf(false) }
                        TextField(value = "Пароль",
                            visualTransformation = if (passwordVisibility) VisualTransformation.None else PasswordVisualTransformation(),
                            leadingIcon = {
                                IconButton(onClick = {
                                    passwordVisibility = !passwordVisibility
                                }) {
                                    if (passwordVisibility) {
                                        Icon(
                                            painter = painterResource(id = R.drawable.eye_close),
                                            contentDescription = ""
                                        )
                                    } else {
                                        Icon(
                                            painter = painterResource(id = R.drawable.eye_open),
                                            contentDescription = ""
                                        )
                                    }
                                }
                            },
                            onValueChange = {})
                        Column(
                            modifier = Modifier
                                .padding(top = 5.dp)
                        )
                        {
                            TextField(
                                value = "Повторите пароль",
                                visualTransformation = if (passwordVisibility) VisualTransformation.None else PasswordVisualTransformation(),
                                leadingIcon = {
                                    IconButton(onClick = {
                                        passwordVisibility = !passwordVisibility
                                    }) {
                                        if (passwordVisibility) {
                                            Icon(
                                                painter = painterResource(id = R.drawable.eye_close),
                                                contentDescription = ""
                                            )
                                        } else {
                                            Icon(
                                                painter = painterResource(id = R.drawable.eye_open),
                                                contentDescription = ""
                                            )
                                        }
                                    }
                                },
                                onValueChange = {},
                            )
                        }
                    }
                    Button(
                        modifier = Modifier.padding(top = 15.dp).height(50.dp),
                        onClick = {
                            viewModel.onSignUpEmail(email.value,password.value)
                        },
                        shape = RoundedCornerShape(23.dp),
                        border = BorderStroke(1.dp, Color(255,215,0)),
                        colors = ButtonDefaults.buttonColors(
                            containerColor = Color(255, 215, 0),
                            contentColor = Color.White
                        )
                    )
                    {
                        Text("ЗАРЕГИСТРИРОВАТЬСЯ", fontSize = 20.sp,
                            color = Color.White,
                            fontWeight = FontWeight.Normal,
                            fontFamily = OldStandart)
                    }
                    Button(
                        modifier = Modifier.padding(top = 5.dp).height(50.dp).width(280.dp),
                        onClick = {},
                        shape = RoundedCornerShape(23.dp),
                        border = BorderStroke(1.dp, Color(255,215,0, 0)),
                        colors = ButtonDefaults.buttonColors(
                            containerColor = Color(255, 215, 0, 0),
                            contentColor = Color.White
                        )
                    )
                    {
                        Text("Продолжить без входа", fontSize = 18.sp,
                            color = Color.White,
                            fontWeight = FontWeight.Normal,
                            fontFamily = OldStandart)
                    }
                }
            }

            Column(
                modifier = Modifier.padding(),
                verticalArrangement = Arrangement.Bottom,
                horizontalAlignment = Alignment.CenterHorizontally
            )
            {
                Text("Или войдите с помощью", fontSize = 16.sp,
                    color = Color.White,
                    fontWeight = FontWeight.Normal,
                    fontFamily = OldStandart)
                Button(
                    modifier = Modifier
                        .padding(top = 10.dp)
                        .height(70.dp)
                        .width(270.dp),
                    onClick = {},
                    colors = ButtonDefaults.buttonColors(
                        containerColor = Color(230, 235, 239, 123),
                        contentColor = Color.Gray
                    ),
                    shape = RoundedCornerShape(10.dp),
                    border = BorderStroke(0.dp, color = Color(230, 235, 239,123))
                )
                {
                    Text(
                        "Войти с Google",
                        fontSize = 20.sp,
                        color = Color.White,
                        fontWeight = FontWeight.Normal,
                        fontFamily = OldStandart
                    )
                }
                Button(
                    modifier = Modifier
                        .padding(top = 10.dp),
                    onClick = {},
                    colors = ButtonDefaults.buttonColors(
                        containerColor = Color(230, 235, 239,0),
                        contentColor = Color.Gray
                    ),
                    border = BorderStroke(0.dp, color = Color(230, 235, 239, 0))
                )
                {
                    Text(
                        "Войти в существующий аккаунт",
                        fontSize = 18.sp,
                        color = Color.White,
                        fontWeight = FontWeight.Normal,
                        fontFamily = OldStandart
                    )
                }
            }
        }
    }
}

@Composable
fun RegistarationScreen2(navController: NavHostController, viewModel: MainViewModel) {
    Box(
        contentAlignment = Alignment.TopCenter,
        modifier = Modifier
            .fillMaxSize()
    )
    {
        Image(
            painter = painterResource(id = R.drawable.fone),
            contentDescription = "",
            contentScale = ContentScale.FillWidth,
            modifier = Modifier.fillMaxWidth().fillMaxHeight()
        )
        Column(modifier = Modifier.fillMaxHeight(), horizontalAlignment = Alignment.CenterHorizontally, verticalArrangement = Arrangement.Center)
        {
            Text("Для завершения регистрации введите следующие данные:",
                color = Color.White,
                modifier = Modifier.padding(bottom = 100.dp),
                fontSize = 20.sp,
                fontWeight = FontWeight.Bold,
                fontFamily = OldStandart
            )
            TextField(
                value = "Фамилия",
                onValueChange = {},
                Modifier.padding(bottom = 10.dp).width(280.dp)
            )
            TextField(
                value = "Имя",
                onValueChange = {},
                Modifier.padding(bottom = 10.dp).width(280.dp)
            )
            TextField(
                value = "Номер телефона",
                onValueChange = {},
                Modifier.padding(bottom = 30.dp).width(280.dp)
            )
            Button(modifier = Modifier
                .width(width = 270.dp)
                .height(height = 40.dp)
                .padding(),
                onClick = {},
                shape = RoundedCornerShape(23.dp),
                border = BorderStroke(0.dp, Color(0xFFEBEBEB)),
                colors = ButtonDefaults.buttonColors(
                    containerColor = Color(255,215,0),
                    contentColor = Color.White)
            )
            {
                Text("СОХРАНИТЬ", color = Color.White,
                    modifier = Modifier.padding(),
                    fontSize = 22.sp,
                    fontWeight = FontWeight.Bold,
                    fontFamily = OldStandart)
            }
        }
    }
}